==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/java/org/gnu/gdk/EventScroll.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.javagnome.Handle;

/**
 *
 */
public class EventScroll extends Event
{
    /**
     * Promotion constructor. Construct the specific event object by
     * promoting (sharing the <tt>Handle</tt> object of) the base
     * <tt>Event</tt>.
     */
    public EventScroll( Event evt ) {
        // We share the handle with both instances.  This avoids
        // copying the event (via the constructor ( super( evt ) ).
        // It is more of a "promotion" constructor.
        super( evt.getHandle() );
    }

    public EventScroll(Handle handle) {
        super(handle);
    }
	
    public ScrollDirection getScrollDirection() {
        return ScrollDirection.intern(getDirection(getHandle()));
    }
    
    public Window getWindow() {
        return Window.getWindowFromHandle(EventScroll.getWindow(getHandle()));
    }

    native static final protected Handle getWindow (Handle obj);
    native static final protected boolean getSendEvent (Handle obj);
    native static final protected int getTime (Handle obj);
    native static final protected double getX (Handle obj);
    native static final protected double getY (Handle obj);
    native static final protected int getState (Handle obj);
    native static final protected int getDirection (Handle obj);
    native static final protected Handle getDevice (Handle obj);
    native static final protected double getXRoot (Handle obj);
    native static final protected double getYRoot (Handle obj);
}

==> libgtk-java-2.8.1.tar.bz2: libgtk-java-2.8.1/src/java/org/gnu/gdk/EventScroll.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gdk;

import org.gnu.glib.Handle;

/**
 *
 */
public class EventScroll extends Event
{
    /**
     * Promotion constructor. Construct the specific event object by
     * promoting (sharing the <tt>Handle</tt> object of) the base
     * <tt>Event</tt>.
     */
    public EventScroll( Event evt ) {
        // We share the handle with both instances.  This avoids
        // copying the event (via the constructor ( super( evt ) ).
        // It is more of a "promotion" constructor.
        super( evt.getHandle() );
    }

    public EventScroll(Handle handle) {
        super(handle);
    }
	
    public ScrollDirection getScrollDirection() {
        return ScrollDirection.intern(getDirection(getHandle()));
    }
    
    public Window getWindow() {
        return Window.getWindowFromHandle(EventScroll.getWindow(getHandle()));
    }

    native static final protected Handle getWindow (Handle obj);
    native static final protected boolean getSendEvent (Handle obj);
    native static final protected int getTime (Handle obj);
    native static final protected double getX (Handle obj);
    native static final protected double getY (Handle obj);
    native static final protected int getState (Handle obj);
    native static final protected int getDirection (Handle obj);
    native static final protected Handle getDevice (Handle obj);
    native static final protected double getXRoot (Handle obj);
    native static final protected double getYRoot (Handle obj);
}
